pub struct Pallet<T>(/* private fields */);Expand description
The Pallet struct, the main type that implements traits and standalone
functions within the pallet.
Implementations
Sourceimpl<T: Config> Pallet<T>
impl<T: Config> Pallet<T>
Sourcepub fn set_custom_validation_head_data(
_: OriginFor<T>,
custom_header: Vec<u8>,
) -> DispatchResult
pub fn set_custom_validation_head_data( _: OriginFor<T>, custom_header: Vec<u8>, ) -> DispatchResult
A test dispatchable for setting a custom head data in validate_block.
Sourcepub fn read_and_write_child_tries(_: OriginFor<T>) -> DispatchResult
pub fn read_and_write_child_tries(_: OriginFor<T>) -> DispatchResult
A dispatchable that first reads two values from two different child tries, asserts they are the expected values (if the values exist in the state) and then writes two different values to these child tries.
Sourcepub fn read_and_write_big_value(_: OriginFor<T>) -> DispatchResult
pub fn read_and_write_big_value(_: OriginFor<T>) -> DispatchResult
Reads a key and writes a big value under this key.
At genesis this key is empty and thus, will only be set in consequent blocks.
Sourcepub fn store_values_in_map(_: OriginFor<T>, max_key: u32) -> DispatchResult
pub fn store_values_in_map(_: OriginFor<T>, max_key: u32) -> DispatchResult
Stores () in TestMap for keys from 0 up to max_key.
Sourcepub fn remove_value_from_map(_: OriginFor<T>, key: u32) -> DispatchResult
pub fn remove_value_from_map(_: OriginFor<T>, key: u32) -> DispatchResult
Removes the value associated with key from TestMap.
Sourcepub fn send_n_upward_messages(_: OriginFor<T>, n: u32) -> DispatchResult
pub fn send_n_upward_messages(_: OriginFor<T>, n: u32) -> DispatchResult
Directly sets n small UMP messages in PendingUpwardMessages.
Sourcepub fn send_upward_message_of_size(_: OriginFor<T>, size: u32) -> DispatchResult
pub fn send_upward_message_of_size(_: OriginFor<T>, size: u32) -> DispatchResult
Sends a UMP message of specific size (in bytes).
Sourcepub fn queue_hrmp_messages(
_: OriginFor<T>,
n: u32,
recipient: ParaId,
) -> DispatchResult
pub fn queue_hrmp_messages( _: OriginFor<T>, n: u32, recipient: ParaId, ) -> DispatchResult
Queues n small HRMP messages to recipient.
Sourcepub fn queue_hrmp_messages_to_n_recipients(
_: OriginFor<T>,
n: u32,
first_recipient: ParaId,
) -> DispatchResult
pub fn queue_hrmp_messages_to_n_recipients( _: OriginFor<T>, n: u32, first_recipient: ParaId, ) -> DispatchResult
Queues one HRMP message each to n consecutive recipients starting from
first_recipient.
Sourcepub fn schedule_weight_registration(_: OriginFor<T>) -> DispatchResult
pub fn schedule_weight_registration(_: OriginFor<T>) -> DispatchResult
Schedule a 1 second weight registration in the next on_initialize.
Sourcepub fn set_inherent_weight_consume(
_: OriginFor<T>,
weight: Weight,
) -> DispatchResult
pub fn set_inherent_weight_consume( _: OriginFor<T>, weight: Weight, ) -> DispatchResult
Set the weight to be consumed by the next inherent call.
Sourcepub fn consume_weight_inherent(origin: OriginFor<T>) -> DispatchResult
pub fn consume_weight_inherent(origin: OriginFor<T>) -> DispatchResult
Consume weight via inherent call (clears the storage after consuming).
Sourcepub fn use_more_weight_than_announced(
_: OriginFor<T>,
_must_be_first_block_in_core: bool,
) -> DispatchResult
pub fn use_more_weight_than_announced( _: OriginFor<T>, _must_be_first_block_in_core: bool, ) -> DispatchResult
This function registers a high weight usage manually, while it actually only announces
to use a weight of 0 :)
Uses the TestTransactionExtension logic to ensure the transaction is only accepted
when we can fit the 1s weight into the block.
Sourcepub fn set_use_full_core(_: OriginFor<T>) -> DispatchResult
pub fn set_use_full_core(_: OriginFor<T>) -> DispatchResult
Deposits the UseFullCore digest item to signal that this block should use the full
core.