pub enum Call<T: Config> {
Show 14 variants
set_custom_validation_head_data {
custom_header: Vec<u8>,
},
read_and_write_child_tries {},
read_and_write_big_value {},
store_values_in_map {
max_key: u32,
},
remove_value_from_map {
key: u32,
},
send_n_upward_messages {
n: u32,
},
send_upward_message_of_size {
size: u32,
},
queue_hrmp_messages {
n: u32,
recipient: ParaId,
},
queue_hrmp_messages_to_n_recipients {
n: u32,
first_recipient: ParaId,
},
schedule_weight_registration {},
set_inherent_weight_consume {
weight: Weight,
},
consume_weight_inherent {},
use_more_weight_than_announced {
must_be_first_block_in_core: bool,
},
set_use_full_core {},
// some variants omitted
}Expand description
Contains a variant per dispatchable extrinsic that this pallet has.
Variants
set_custom_validation_head_data
A test dispatchable for setting a custom head data in validate_block.
read_and_write_child_tries
A dispatchable that first reads two values from two different child tries, asserts they are the expected values (if the values exist in the state) and then writes two different values to these child tries.
read_and_write_big_value
Reads a key and writes a big value under this key.
At genesis this key is empty and thus, will only be set in consequent blocks.
store_values_in_map
Stores () in TestMap for keys from 0 up to max_key.
remove_value_from_map
Removes the value associated with key from TestMap.
send_n_upward_messages
Directly sets n small UMP messages in PendingUpwardMessages.
send_upward_message_of_size
Sends a UMP message of specific size (in bytes).
queue_hrmp_messages
Queues n small HRMP messages to recipient.
queue_hrmp_messages_to_n_recipients
Queues one HRMP message each to n consecutive recipients starting from
first_recipient.
schedule_weight_registration
Schedule a 1 second weight registration in the next on_initialize.
set_inherent_weight_consume
Set the weight to be consumed by the next inherent call.
consume_weight_inherent
Consume weight via inherent call (clears the storage after consuming).
use_more_weight_than_announced
This function registers a high weight usage manually, while it actually only announces
to use a weight of 0 :)
Uses the TestTransactionExtension logic to ensure the transaction is only accepted
when we can fit the 1s weight into the block.
set_use_full_core
Deposits the UseFullCore digest item to signal that this block should use the full
core.
Implementations
Sourceimpl<T: Config> Call<T>
impl<T: Config> Call<T>
Sourcepub fn new_call_variant_set_custom_validation_head_data(
custom_header: Vec<u8>,
) -> Self
pub fn new_call_variant_set_custom_validation_head_data( custom_header: Vec<u8>, ) -> Self
Create a call with the variant set_custom_validation_head_data.
Sourcepub fn new_call_variant_read_and_write_child_tries() -> Self
pub fn new_call_variant_read_and_write_child_tries() -> Self
Create a call with the variant read_and_write_child_tries.
Sourcepub fn new_call_variant_read_and_write_big_value() -> Self
pub fn new_call_variant_read_and_write_big_value() -> Self
Create a call with the variant read_and_write_big_value.
Sourcepub fn new_call_variant_store_values_in_map(max_key: u32) -> Self
pub fn new_call_variant_store_values_in_map(max_key: u32) -> Self
Create a call with the variant store_values_in_map.
Sourcepub fn new_call_variant_remove_value_from_map(key: u32) -> Self
pub fn new_call_variant_remove_value_from_map(key: u32) -> Self
Create a call with the variant remove_value_from_map.
Sourcepub fn new_call_variant_send_n_upward_messages(n: u32) -> Self
pub fn new_call_variant_send_n_upward_messages(n: u32) -> Self
Create a call with the variant send_n_upward_messages.
Sourcepub fn new_call_variant_send_upward_message_of_size(size: u32) -> Self
pub fn new_call_variant_send_upward_message_of_size(size: u32) -> Self
Create a call with the variant send_upward_message_of_size.
Sourcepub fn new_call_variant_queue_hrmp_messages(n: u32, recipient: ParaId) -> Self
pub fn new_call_variant_queue_hrmp_messages(n: u32, recipient: ParaId) -> Self
Create a call with the variant queue_hrmp_messages.
Sourcepub fn new_call_variant_queue_hrmp_messages_to_n_recipients(
n: u32,
first_recipient: ParaId,
) -> Self
pub fn new_call_variant_queue_hrmp_messages_to_n_recipients( n: u32, first_recipient: ParaId, ) -> Self
Create a call with the variant queue_hrmp_messages_to_n_recipients.
Sourcepub fn new_call_variant_schedule_weight_registration() -> Self
pub fn new_call_variant_schedule_weight_registration() -> Self
Create a call with the variant schedule_weight_registration.
Sourcepub fn new_call_variant_set_inherent_weight_consume(weight: Weight) -> Self
pub fn new_call_variant_set_inherent_weight_consume(weight: Weight) -> Self
Create a call with the variant set_inherent_weight_consume.
Sourcepub fn new_call_variant_consume_weight_inherent() -> Self
pub fn new_call_variant_consume_weight_inherent() -> Self
Create a call with the variant consume_weight_inherent.
Sourcepub fn new_call_variant_use_more_weight_than_announced(
must_be_first_block_in_core: bool,
) -> Self
pub fn new_call_variant_use_more_weight_than_announced( must_be_first_block_in_core: bool, ) -> Self
Create a call with the variant use_more_weight_than_announced.
Sourcepub fn new_call_variant_set_use_full_core() -> Self
pub fn new_call_variant_set_use_full_core() -> Self
Create a call with the variant set_use_full_core.